@@ -1,6 +1,10 @@
+from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 def _get_status_condition_log_message(**status_condition):
     log_msg = "Waiting For: \n"
     for status_condition_name, status_condition in status_condition.items():
@@ -21,6 +25,7 @@ class MTV:
         Migration
         StorageMap
         NetworkMap
+        Host
     """
 
     def __init__(self):
@@ -51,6 +56,7 @@ class MTV:
         MIGRATION_READY = "The migration is ready."
         MIGRATION_RUNNING = "The migration is RUNNING"
         MIGRATION_SUCCEEDED = "The migration has SUCCEEDED."
+        HOST_READY = "The host is ready."
 
     class ProviderType:
         VSPHERE = "vsphere"
@@ -70,7 +76,7 @@ class MTV:
         Wait for MTV Resource Status Conditions.
         """
 
-        self.logger.info(
+        LOGGER.info(
             _get_status_condition_log_message(
                 condition_status=condition_status,
                 condition_type=condition_type,
@@ -83,7 +89,7 @@ class MTV:
         samples = TimeoutSampler(
             wait_timeout=wait_timeout,
             sleep=1,
-            func=self.api().get,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -118,7 +124,7 @@ class MTV:
                         return
 
         except TimeoutExpiredError:
-            self.logger.error(
+            LOGGER.error(
                 msg=f"Last Status Condition of {self.kind} {self.name} was: {last_condition}"
             )
             raise
