@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-from openshift.dynamic.exceptions import ResourceNotFoundError
-from urllib3.exceptions import ProtocolError
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachineRestore(NamespacedResource):
     """
     VirtualMachineRestore object.
@@ -17,16 +19,30 @@ class VirtualMachineRestore(NamespacedResource):
     api_group = NamespacedResource.ApiGroup.SNAPSHOT_KUBEVIRT_IO
 
     def __init__(
-        self, name, namespace, vm_name, snapshot_name, client=None, teardown=True
+        self,
+        name=None,
+        namespace=None,
+        vm_name=None,
+        snapshot_name=None,
+        client=None,
+        teardown=True,
+        yaml_file=None,
     ):
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.vm_name = vm_name
         self.snapshot_name = snapshot_name
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         spec = res.setdefault("spec", {})
         spec.setdefault("target", {})[
             "apiGroup"
@@ -47,40 +63,17 @@ class VirtualMachineRestore(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be complete = {status}"
         )
 
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions=ProtocolError,
+            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
             func=lambda: self.instance.get("status", {}).get("complete", None)
             == status,
         )
         for sample in samples:
             if sample:
                 return
-
-    def wait_restore_done(self, timeout=TIMEOUT_4MINUTES):
-        """
-        Wait for the the restore to be done. This check 2 parameters, the restore status to be complete
-        and the VM status restoreInProgress to be None.
-
-        Args:
-            timeout (int): Time to wait.
-
-        Raises:
-            TimeoutExpiredError: If timeout reached.
-        """
-        self.wait_complete(timeout=timeout)
-
-        vm = VirtualMachine(
-            client=self.client,
-            namespace=self.namespace,
-            name=self.vm_name,
-        )
-
-        if vm.exists:
-            return vm.wait_for_status_none(status="restoreInProgress", timeout=timeout)
-        raise ResourceNotFoundError(f"VirtualMachine: {vm.name} not found")
